import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  format,
  line,
  area,
  curveBasis
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

// Format the value to show on the Areachart
const xAxisTickFormat = number =>
    format('.2s')(number)

const render = data => {
  
  const xValue = d => d.Year;
  const xAxisLabel = 'Year';
  
  const yValue = d => d.Height;
  const circleRadius = 7;
  const yAxisLabel = 'Height';
  
  const margin = { top: 10, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;  
//  Scale for X axis
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([1, innerWidth])
    .nice();
//  Scale for Y axis  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 1])
    .nice();
 
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
 // Assigning values to x axis 
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
 // Assigning values to y axis  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15)
    .tickFormat(xAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .text(xAxisLabel);
 
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveBasis);
 
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class', 'line-chart')
  	.attr('d', lineGenerator(data));
  
  g.append('path')
  	.attr('class', 'area-chart')
  	.attr('d', areaGenerator(data));
  
 
};
// Loading and Parsing CSV data
csv('https://gist.githubusercontent.com/saidhiraj16/f007eba20b98222d9aeb95d8bcdb8a50/raw/b34c70a3ff1c80845372ffc047a3eaffc0cf21c1/WorldHeight.csv')
  .then(data => {
    data.forEach(d => {
      d.Height = +d.Height;

      
    });
    render(data);
  	console.log(data);
  });